@@ -183,12 +183,48 @@ class GSPeerConnectionWatcherNew:
         @self.sio.event
         async def bjoined(id):
             self.logger.info("broadcaster received")
-            await self.sio.emit("broadcaster", {"id": id, "target": self.target})
+            # await self.sio.emit("broadcaster", {"id": id, "target": self.target,"emitter":"js"})
 
         @self.sio.event
         async def joined(id):
             self.logger.info("calling broadcaster")
-            await self.sio.emit("broadcaster", {"id": id, "target": self.target})
+            # await self.sio.emit("broadcaster", {"id": id, "target": self.target})
+
+        @self.sio.event
+        async def broadcaster(id,target,emitter):
+            if len(self.rtconfiList) > 0:
+                self.peerConnections = RTCPeerConnection(configuration=RTCConfiguration(self.rtconfiList))
+            else:
+                self.peerConnections = RTCPeerConnection()
+
+            self.peerConnections.addTransceiver('video', direction='recvonly')
+
+            @self.peerConnections.on("iceconnectionstatechange")
+            async def on_iceconnectionstatechange():
+                if self.peerConnections.iceConnectionState == "complete":
+                    pass
+
+                if self.peerConnections.iceConnectionState == "failed":
+                    await self.peerConnections.close()
+
+            @self.peerConnections.on("track")
+            async def on_track(track):
+                if track.kind == "video":
+                    if self.ontrack is not None:
+                        self.logger.info("on track received.Recording started")
+                        await self.ontrack(self.gsdbs, track, self.target)
+                    if self.onframe is not None:
+                        self.logger.info("on track received. onframe started")
+                        gsmediaconsumer = GSMediaConsumer(self.gsdbs, self.target, self.onframe)
+                        gsmediaconsumer.addTrack(track)
+                        await gsmediaconsumer.start()
+
+            await self.peerConnections.setLocalDescription(await self.peerConnections.createOffer())
+            await self.sio.emit("watcher",
+                                {"target": self.target,
+                                 "id":id,
+                                 "sdp": {"type": self.peerConnections.localDescription.type,
+                                         "sdp": self.peerConnections.localDescription.sdp}})
 
         @self.sio.event
         async def watcher(id, description):
@@ -222,6 +258,15 @@ class GSPeerConnectionWatcherNew:
                                  "message": {"type": self.peerConnections.localDescription.type,
                                              "sdp": self.peerConnections.localDescription.sdp}})
 
+        @self.sio.event
+        async def answer(id, description):
+            if self.peerConnections.signalingState != "stable":
+                if isinstance(description, dict):
+                    desc = type('new_dict', (object,), description)
+                else:
+                    desc = type('new_dict', (object,), ast.literal_eval(description))
+                await self.peerConnections.setRemoteDescription(desc)
+
         @self.sio.event
         async def disconnect():
             self.logger.info("Socket connection list")
@@ -246,7 +291,7 @@ class GSPeerConnectionWatcherNew:
             connectURL = self.gsdbs.credentials["signalserver"]
 
         await self.sio.connect(
-            f'{connectURL}?gssession={self.gsdbs.cookiejar.get("session")}.{self.gsdbs.cookiejar.get("signature")}{self.gsdbs.credentials["cnode"]}&target={self.target}')
+            f'{connectURL}?gssession={self.gsdbs.cookiejar.get("session")}.{self.gsdbs.cookiejar.get("signature")}{self.gsdbs.credentials["cnode"]}&target={self.target}&terminator=true')
         await self.sio.wait()
 
 
@@ -271,6 +316,8 @@ class FrameBufferThread(Thread):
             buf = self.nal_queue.get()
             if buf is not None or buf:
                 self.onframe(self.gsdbs, self.target, buf, self.framerate)
+
+
 class GSMediaConsumer:
 
     def __init__(self, gsdbs, target, onframe):
@@ -316,6 +363,7 @@ class GSMediaConsumer:
                 task.cancel()
         self.__tracks = {}
 
+
 class FrameBufferThreadAsync():
     def __init__(self, gsdbs, target, onframe):
         self.gsdbs = gsdbs
@@ -372,7 +420,6 @@ class GSMediaConsumerAsync:
                 self.__tracks[track] = asyncio.ensure_future(
                     self.stream_consume(track, self.gsdbs, self.target, self.onframe))
 
-
     async def stream_consume(self, track, gsdbs, target, onframe):
         while True:
             try:
@@ -389,6 +436,3 @@ class GSMediaConsumerAsync:
             if task is not None:
                 task.cancel()
         self.__tracks = {}
-
-
-
